# django-admin-honeypot

[![Build Status](https://secure.travis-ci.org/dmpayton/django-admin-honeypot.png?branch=develop)](http://travis-ci.org/dmpayton/django-admin-honeypot)
[![Coverage Status](https://coveralls.io/repos/dmpayton/django-admin-honeypot/badge.png?branch=develop)](https://coveralls.io/r/dmpayton/django-admin-honeypot?branch=develop)
[![Downloads](https://pypip.in/d/django-admin-honeypot/badge.png)](https://pypi.python.org/pypi/django-admin-honeypot)
[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/dmpayton/django-admin-honeypot/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

django-admin-honeypot is a fake Django admin login screen to log and notify
admins of attempted unauthorized access. This app was inspired by discussion
in and around Paul McMillan's security talk at DjangoCon 2011.

* **Author**: [Derek Payton](http://dmpayton.com)
* **Version**: 0.3.0
* **License**: MIT

## Documentation

http://django-admin-honeypot.readthedocs.org

### tl;dr

```
pip install django-admin-honeypot
```

* Add `admin_honeypot` to `INSTALLED_APPS`
* Update your urls.py:

    ```
    urlpatterns = patterns(''
        ...
        url(r'^admin/', include('admin_honeypot.urls')),
        url(r'^secret/', include(admin.site.urls)),
    )
    ```
